pub struct NoOutputFileSystem<C: Character> {
pub kpse: Kpathsea,
pub envs: HMap<String, String>,
pub interner: StringInterner<StringBackend<SymbolU32>, FxBuildHasher>,
/* private fields */
}Expand description
A FileSystem that does not write to the local physical file system.
If a file is modified, its contents are kept in memory.
Fields
kpse: Kpathseaenvs: HMap<String, String>interner: StringInterner<StringBackend<SymbolU32>, FxBuildHasher>Implementations