pub struct VirtualFile<C: Character> {
pub path: PathBuf,
pub pipe: bool,
pub id: Option<SymbolU32>,
pub source: Option<Ptr<[TextLine<C>]>>,
pub exists: bool,
}Expand description
A File that may live in memory or on the physical file system.
Fields
path: PathBufpipe: boolid: Option<SymbolU32>source: Option<Ptr<[TextLine<C>]>>exists: boolTrait Implementations
Sourceimpl<C: Clone + Character> Clone for VirtualFile<C>
impl<C: Clone + Character> Clone for VirtualFile<C>
Sourcefn clone(&self) -> VirtualFile<C>
fn clone(&self) -> VirtualFile<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Character> Display for VirtualFile<C>
impl<C: Character> Display for VirtualFile<C>
Sourceimpl<C: Character> File for VirtualFile<C>
impl<C: Character> File for VirtualFile<C>
Sourcetype LineSource = VirtualFileLineSource<C>
type LineSource = VirtualFileLineSource<C>
The type of line sources to be read from the file.
Sourcetype SourceRefID = Option<SymbolU32>
type SourceRefID = Option<SymbolU32>
A
Copyable identifier for this file to be used in SourceReferences.Sourcefn sourceref(&self) -> Self::SourceRefID
fn sourceref(&self) -> Self::SourceRefID
Returns a
SourceRefID for this file.Sourcefn line_source(self) -> Result<Self::LineSource, PathBuf>
fn line_source(self) -> Result<Self::LineSource, PathBuf>
Returns a line source for this file. Used by a
Mouth to read from this file.Sourceimpl<C: Character> FileWithMD5 for VirtualFile<C>
impl<C: Character> FileWithMD5 for VirtualFile<C>