File

Trait File 

pub trait File:
    Display
    + Clone
    + Debug
    + 'static {
    type Char: Character;
    type SourceRefID: Copy + Debug + Default;
    type LineSource: FileLineSource<Self::Char>;

    // Required methods
    fn path(&self) -> &Path;
    fn line_source(self) -> Result<Self::LineSource, PathBuf>;
    fn size(&self) -> usize;
    fn sourceref(&self) -> Self::SourceRefID;

    // Provided method
    fn exists(&self) -> bool { ... }
}
A (virtual or physical) file.

Required Associated Types

type Char: Character

The type of characters to be read from the file.

type SourceRefID: Copy + Debug + Default

A Copyable identifier for this file to be used in SourceReferences.

type LineSource: FileLineSource<Self::Char>

The type of line sources to be read from the file.

Required Methods

fn path(&self) -> &Path

Returns the path of this file.

fn line_source(self) -> Result<Self::LineSource, PathBuf>

Returns a line source for this file. Used by a Mouth to read from this file.

fn size(&self) -> usize

Returns the size of this file in bytes.

fn sourceref(&self) -> Self::SourceRefID

Returns a SourceRefID for this file.

Provided Methods

fn exists(&self) -> bool

Returns whether this file exists.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors